@@ -41,7 +41,7 @@ use Carp;
 @ISA = qw(Exporter DBI::Shell::Std);
 @EXPORT = qw(shell);
 
-$VERSION = '11.95_01';
+$VERSION = '11.95_02';
 
 my $warning = <<'EOM';
 
@@ -139,6 +139,7 @@ use DBI 1.00 qw(:sql_types :utils);
 use DBI::Format;
 
 use DBI::Shell::FindSqlFile;
+use IO::Interactive qw/ is_interactive /;
 
 use vars qw(@ISA);
 @ISA = qw(DBI::Shell::FindSqlFile);
@@ -414,7 +415,7 @@ sub default_term {
     # Setup Term
     #
     my $mode;
-    if ($sh->{batch} || ! -t STDIN) {
+    if (is_interactive()) {
 		$sh->{batch} = 1;
 		$mode = "in batch mode";
     } else {
